kache_hive_ce library
Hive CE persistence integration for Kache.
Classes
-
HiveCeBinding<
T> -
Opaque Hive CE persistence configuration for values of type
T. -
HiveCeCodec<
T> - Encodes and decodes one application model for Hive CE persistence.
- HiveCeKacheStore
- A Hive CE persistence backend using versioned byte envelopes.
Enums
- HiveCeBoxOwnership
- Determines whether a store closes an injected Hive box.
Typedefs
-
HiveCeMigrator<
T> = T Function(Uint8List payload, int fromSchema) - Migrates an older schema payload into the binding's current typed value.